@@ -9,6 +9,6 @@ __title__ = "pypxl"
 __author__ = "Kile"
 __license__ = "MIT"
 __copyright__ = "Copyright 2021 Kile"
-__version__ = "0.1.8"
+__version__ = "0.2.0"
 
-from .client import Pxlapi
\ No newline at end of file
+from .client import PxlClient
\ No newline at end of file
